==> eslint-plugin-woke-0.1.0.tgz: package/lib/categories/racism.js <==
module.exports = [
  {
    description: '"{word}" could be seen as insensitive',
    words: ['blacklist', 'whitelist', 'master', 'slave', 'blackball']
  }, {
    description: '"{word}" is an offensive term',
    words: [
      'af', 'ape', 'bluegum', 'boogie', 'buck', 'burrhead', 'colored', 'coon', 'crow',
      'eggplant', 'fuzzies', 'golliwogg', 'jigaboo', 'jiggabo', 'jijjiboo', 'zigabo', 'jig',
      'jigg', 'jiggy', 'jigga', 'kaffir', 'kaffer', 'kafir', 'kaffre', 'macaca', 'mammy', 'monkey',
      'mosshead', 'munt', 'nigger', 'nigra', 'nigga', 'niggah', 'nigguh', 'niglet', 'nigglet', 'nigra',
      'negra', 'niggra', 'nigrah', 'nigruh', 'pickaninny', 'quashie', 'sambo', 'sooty', 'spade',
      'spook', 'teapot', 'thicklips', 'bootlips'
    ]
  }, {
    description: '"{word}" is an offensive term for an aboriginal Australian',
    words: ['abo', 'abbo', 'boong', 'bong', 'bung', 'coon', 'gin', 'lubra']
  }, {
    description: '"{word}" is an offensive term for an East Asian',
    words: ['celestial', 'charlie', 'chinaman', 'chink', 'coolie', 'gook', 'jap', 'nip', 'oriental', 'yellow', 'yellowman']
  }, {
    description: '"{word}" is an offensive term for a South Asian',
    words: ['paki', 'hajji', 'hadji', 'haji', 'malaun', 'brownie']
  }, {
    description: '"{word}" is an offensive term for a Southeast Asian',
    words: ['brownie', 'chinki', 'jakun']
  }, {
    description: '"{word}" is an offensive term for a Middle Easterner',
    words: ['brownie', 'towelhead', 'raghead']
  }, {
    description: '"{word}" is an offensive term for an Alaska native',
    words: ['eskimo']
  }, {
    description: '"{word}" is an offensive term for a Latin American/Hispanic person',
    words: ['spic', 'spick', 'spik', 'spig', 'brownie', 'wetback', 'greaseball', 'beaner', 'greaser', 'tacohead']
  }, {
    description: '"{word}" is an offensive term for a European',
    words: [
      'bule', 'charlie', 'cracker', 'farang', 'gammon', 'gringo', 'gubba', 'gweilo', 'gwailo',
      'hunky', 'bohunk', 'medigan', 'ofay', 'arkie', 'okie', 'peckerwood'
    ]
  }, {
    description: '"{word}" is an offensive term for a Mediterranean/Southern European',
    words: ['chocko', 'dago', 'greaseball', 'greaser', 'kanake', 'métèque', 'wog']
  }, {
    description: '"{word}" is an offensive term for a Native American',
    words: ['redskin', 'injun', 'brownie', 'chug', 'squaw']
  }, {
    description: '"{word}" is an offensive term for a Pacific Islander',
    words: ['boonga', 'boong', 'bunga', 'boonie', 'brownie', 'kanaka', 'hori']
  }, {
    description: '"{word}" is an offensive term for an American',
    words: ['merkin', 'yankee', 'yank', 'seppo', 'septic']
  }, {
    description: '"{word}" is an offensive term for a white American',
    words: ['cracker', 'redneck', 'hillbilly', 'trash', 'hick', 'bumpkin', 'peckerwood', 'whitey']
  }, {
    description: '"{word}" is an offensive term for Britons',
    words: ['limey', 'pom', 'pommy']
  }, {
    description: '"{word}" is an offensive term for Germans',
    words: ['boches', 'chleuh', 'hermans', 'herms', 'jerry', 'gerry', 'kraut', 'marmeladinger', 'mof', 'piefke']
  }, {
    description: '"{word}" is an offensive term for an Irish person',
    words: ['mick', 'paddy', 'prod', 'taig', 'snout']
  }, {
    description: '"{word}" is an offensive term for a Italians',
    words: ['dago', 'ginzo', 'goombah', 'greaseball', 'greaser', 'guido', 'guinea', 'polentone', 'terrone', 'wog', 'wop']
  }, {
    description: '"{word}" is an offensive term for a Jew',
    words: ['kike', 'kyke', 'shylock', 'yid']
  }, {
    description: '"{word}" is an offensive term for a Lebanese',
    words: ['lebo', 'lebbo', 'wog']
  }, {
    description: '"{word}" is an offensive term for Macedonians',
    words: ['bulgaroskopian', 'macedonist', 'pseudomacedonian', 'skopjan', 'skopjian', 'skopiana', 'skopianika']
  }, {
    description: '"{word}" is an offensive term for a Finnish person',
    words: ['chukhna']
  }, {
    description: '"{word}" is an offensive term for a Polish person',
    words: ['polack', 'polak', 'pollack', 'pollock', 'polock', 'pshek']
  }, {
    description: '"{word}" is an offensive term for Russians',
    words: ['russki', 'russkie']
  }, {
    description: '"{word}" is an offensive term for Chinese people',
    words: ['tiong', 'cheena', 'chinaman', 'ching', 'chang', 'chong', 'chink', 'chinky', 'chonky', 'coolie', 'slope', 'panface', 'lingling']
  }, {
    description: '"{word}" is an offensive term for Japanese people',
    words: ['jap', 'nip']
  }, {
    description: '"{word}" is an offensive term for Korean people',
    words: ['gook', 'kimchi']
  }, {
    description: '"{word}" is an offensive term for Filipino people',
    words: ['gugus', 'flip']
  }, {
    description: '"{word}" is an offensive term for Ukrainian people',
    words: ['bohunk', 'khokhol', 'saloyed', 'ukr', 'ukrop']
  }, {
    description: '"{word}" is a African-European cross ethnic slur',
    words:['mulatto', 'oreo', 'ann', 'wigger', 'wegro']
  }, {
    description: '"{word}" is a Native American-African cross ethnic slur',
    words:['mulatto', 'zambo', 'lobos']
  }, {
    description: '"{word}" is a Native American-European cross ethnic slur',
    words: ['mulatto', 'apple']
  }, {
    description: '"{word}" is a South Asian-European cross ethnic slur',
    words: ['abcd']
  }, {
    description: '"{word}" is a East Asian-European cross ethnic slur',
    words: ['banana']
  }, {
    description: '"{word}" is a Pacific Islander/Latin American cross ethnic slur',
    words: ['coconut']
  }
];


// copy(Array.from($0.getElementsByTagName('dt'))
// .map(e => e.innerText)
// .reduce((a, v) => a.concat(v.split(/[\/,]| and /g).map(vv => vv.trim().toLowerCase())),[])
// .filter(v => !v.includes(' '))
// .filter(v => !v.includes('-')))

==> eslint-plugin-woke-1.0.1.tgz: package/lib/categories/racism.js <==
module.exports = [
  {
    description: '"{word}" could be seen as insensitive',
    words: [
      ['black','list'], ['white','list'], 'master', 'slave',
      ['black','ball'], ['white','wash'], ['white','washed']
    ]
  }, {
    description: '"{word}" is an offensive term for an African person',
    words: [
      'af', 'ape', ['blue','gum'], 'boogie', 'buck', ['burr','head'], 'colored', 'coon', 'crow',
      ['egg','plant'], 'fuzzies', 'golliwogg', 'jigaboo', 'jiggabo', 'jijjiboo', 'zigabo', 'jig',
      'jigg', 'jiggy', 'jigga', 'kaffir', 'kaffer', 'kafir', 'kaffre', 'macaca', 'mammy', 'monkey',
      'mosshead', 'munt', 'nigger', 'nigra', 'nigga', 'niggah', 'nigguh', 'niglet', 'nigglet', 'nigra',
      'negra', 'niggra', 'nigrah', 'nigruh', 'pickaninny', 'quashie', 'sambo', 'sooty', 'spade',
      'spook', 'teapot', ['thick','lips'], ['boot','lips']
    ]
  }, {
    description: '"{word}" is an offensive term for an aboriginal Australian',
    words: ['abo', 'abbo', 'boong', 'bong', 'bung', 'coon', 'gin', 'lubra']
  }, {
    description: '"{word}" is an offensive term for an East Asian',
    words: [
      'celestial', 'charlie', ['china','man'], 'chink', 'coolie', 'gook', 'jap',
      'nip', 'oriental', 'yellow', 'yellowman'
    ]
  }, {
    description: '"{word}" is an offensive term for a South Asian',
    words: ['paki', 'hajji', 'hadji', 'haji', 'malaun', 'brownie']
  }, {
    description: '"{word}" is an offensive term for a Southeast Asian',
    words: ['brownie', 'chinki', 'jakun']
  }, {
    description: '"{word}" is an offensive term for a Middle Easterner',
    words: ['brownie', ['towel','head'], ['rag','head']]
  }, {
    description: '"{word}" is an offensive term for an Alaska native',
    words: ['eskimo']
  }, {
    description: '"{word}" is an offensive term for a latin American/Hispanic person',
    words: [
      'spic', 'spick', 'spik', 'spig', 'brownie', ['wet','back'], ['grease','ball'],
      'beaner', 'greaser', ['taco','head']
    ]
  }, {
    description: '"{word}" is an offensive term for a European',
    words: [
      'bule', 'charlie', 'cracker', 'farang', 'gammon', 'gringo', 'gubba', 'gweilo', 'gwailo',
      'hunky', 'bohunk', 'medigan', 'ofay', 'arkie', 'okie', ['pecker','wood']
    ]
  }, {
    description: '"{word}" is an offensive term for a Mediterranean/Southern European',
    words: ['chocko', 'dago', ['grease','ball'], 'greaser', 'kanake', 'métèque', 'wog']
  }, {
    description: '"{word}" is an offensive term for a native American',
    words: ['redskin', 'injun', 'brownie', 'chug', 'squaw']
  }, {
    description: '"{word}" is an offensive term for a Pacific Islander',
    words: ['boonga', 'boong', 'bunga', 'boonie', 'brownie', 'kanaka', 'hori']
  }, {
    description: '"{word}" is an offensive term for an American',
    words: ['merkin', 'yankee', 'yank', 'seppo', 'septic']
  }, {
    description: '"{word}" is an offensive term for a white American',
    words: ['cracker', 'redneck', ['hill','billy'], 'trash', 'hick', 'bumpkin', ['pecker','wood'], 'whitey']
  }, {
    description: '"{word}" is an offensive term for Britons',
    words: ['limey', 'pom', 'pommy']
  }, {
    description: '"{word}" is an offensive term for Germans',
    words: ['boches', 'chleuh', 'hermans', 'herms', 'jerry', 'gerry', 'kraut', 'marmeladinger', 'mof', 'piefke']
  }, {
    description: '"{word}" is an offensive term for an Irish person',
    words: ['mick', 'paddy', 'prod', 'taig', 'snout']
  }, {
    description: '"{word}" is an offensive term for a Italians',
    words: ['dago', 'ginzo', 'goombah', ['grease','ball'], 'greaser', 'guido', 'guinea', 'polentone', 'terrone', 'wog', 'wop']
  }, {
    description: '"{word}" is an offensive term for a Jew',
    words: ['kike', 'kyke', 'shylock', 'yid']
  }, {
    description: '"{word}" is an offensive term for a Lebanese',
    words: ['lebo', 'lebbo', 'wog']
  }, {
    description: '"{word}" is an offensive term for Macedonians',
    words: ['bulgaroskopian', 'macedonist', 'pseudomacedonian', 'skopjan', 'skopjian', 'skopiana', 'skopianika']
  }, {
    description: '"{word}" is an offensive term for a Finnish person',
    words: ['chukhna']
  }, {
    description: '"{word}" is an offensive term for a Polish person',
    words: ['polack', 'polak', 'pollack', 'pollock', 'polock', 'pshek']
  }, {
    description: '"{word}" is an offensive term for Russians',
    words: ['russki', 'russkie']
  }, {
    description: '"{word}" is an offensive term for Chinese people',
    words: ['tiong', 'cheena', 'chinaman', 'ching', 'chang', 'chong', 'chink', 'chinky', 'chonky', 'coolie', 'slope', ['pan','face'], ['ling','ling']]
  }, {
    description: '"{word}" is an offensive term for Japanese people',
    words: ['jap', 'nip']
  }, {
    description: '"{word}" is an offensive term for Korean people',
    words: ['gook', 'kimchi']
  }, {
    description: '"{word}" is an offensive term for Filipino people',
    words: ['gugus', 'flip']
  }, {
    description: '"{word}" is an offensive term for Ukrainian people',
    words: ['bohunk', 'khokhol', 'saloyed', 'ukr', 'ukrop']
  }, {
    description: '"{word}" is a African-European cross ethnic slur',
    words:['mulatto', 'oreo', 'ann', 'wigger', 'wegro']
  }, {
    description: '"{word}" is a Native American-African cross ethnic slur',
    words:['mulatto', 'zambo', 'lobos']
  }, {
    description: '"{word}" is a Native American-European cross ethnic slur',
    words: ['mulatto', 'apple']
  }, {
    description: '"{word}" is a South Asian-European cross ethnic slur',
    words: ['abcd']
  }, {
    description: '"{word}" is a East Asian-European cross ethnic slur',
    words: ['banana']
  }, {
    description: '"{word}" is a Pacific Islander/Latin American cross ethnic slur',
    words: ['coconut']
  }
];
